# Cusum

Package for processing Cumulative Sum change detection algorithm from downloading SAR images to visual shapefile result

### Environment Setup

Start with creating a dedicated environment with conda, installing python 3.9 and gdal. In a terminal or command prompt : 

`conda create -n my_env python=3.9 gdal=3.6.4`

### Install

In a terminal, activate your dedicated environment : 

`conda activate my_env`

Install the cusum package using pip : 

`pip install cusum`

